aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorGravatar Miklos Szeredi <miklos@szeredi.hu>2005-08-23 15:39:43 +0000
committerGravatar Miklos Szeredi <miklos@szeredi.hu>2005-08-23 15:39:43 +0000
commitb0c52c59f710b4619949adfc359dabfca005fe0d (patch)
treeded91b7758b4c99506cdaa112446df40c8bab514 /include
parent9724d546a61d031eb0fa2ae5f64e26b7f77c781b (diff)
fix
Diffstat (limited to 'include')
-rw-r--r--include/fuse.h2
-rw-r--r--include/fuse_lowlevel.h8
2 files changed, 9 insertions, 1 deletions
diff --git a/include/fuse.h b/include/fuse.h
index 4bb215e..6251158 100644
--- a/include/fuse.h
+++ b/include/fuse.h
@@ -311,6 +311,8 @@ struct fuse_operations {
* Introduced in version 2.4
*/
int (*access) (const char *, int);
+
+ int (*create) (const char *, mode_t, struct fuse_file_info *);
};
/** Extra context that may be needed by some filesystems
diff --git a/include/fuse_lowlevel.h b/include/fuse_lowlevel.h
index ffeb6f9..a8e3e3e 100644
--- a/include/fuse_lowlevel.h
+++ b/include/fuse_lowlevel.h
@@ -95,6 +95,8 @@ struct fuse_lowlevel_ops {
fuse_ino_t newparent, const char *newname);
void (*link) (fuse_req_t req, fuse_ino_t ino, fuse_ino_t newparent,
const char *newname);
+ void (*create) (fuse_req_t req, fuse_ino_t parent, const char *name,
+ mode_t mode, struct fuse_file_info *fi);
void (*open) (fuse_req_t req, fuse_ino_t ino, struct fuse_file_info *fi);
void (*read) (fuse_req_t req, fuse_ino_t ino, size_t size, off_t off,
struct fuse_file_info *fi);
@@ -132,9 +134,13 @@ int fuse_reply_err(fuse_req_t req, int err);
/* forget */
int fuse_reply_none(fuse_req_t req);
/* lookup, mknod, mkdir, symlink, link */
int fuse_reply_entry(fuse_req_t req, const struct fuse_entry_param *e);
+/* create */
+int fuse_reply_create(fuse_req_t req, const struct fuse_entry_param *e,
+ const struct fuse_file_info *fi);
+
/* getattr, setattr */
int fuse_reply_attr(fuse_req_t req, const struct stat *attr,
double attr_timeout);
@@ -132,9 +134,13 @@ int fuse_reply_err(fuse_req_t req, int err);
/* forget */
int fuse_reply_none(fuse_req_t req);
-/* lookup, mknod, mkdir, symlink, link */
+/* lookup, create, mknod, mkdir, symlink, link */
int fuse_reply_entry(fuse_req_t req, const struct fuse_entry_param *e);